import pathlib
import setuptools

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setuptools.setup(
    name="pihat-widget",
    version="1.1.8",
    description="Widgets for Python programming practise",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/chrisf17/pihat-widgets",
    author="Chris Farrell",
    author_email="pihat@xivuh.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    packages=setuptools.find_packages(),


    include_package_data=True,
    install_requires=[],

)